# ShowSquareClass
""" Illustrates the difference between copy and deepcopy
using a simple class for squares.
"""

from copy import *
from SimpleGraphics import *

class Square:
    """
    For representing a square with side s, lower left corner at (x,y),
    and color c
    
    attributes:
         s  positive float
         x  float
         y  float
         c  length-3 list of floats that is an rgb list.
    """
    
    def __init__(self,x,y,s,c):
        self.s = s
        self.x = x
        self.y = y
        self.c = c

def DrawSquare(S):
   """ Draws square S
   
   PreC: S is a square
   """
   # Get the center
   x = S.x + S.s/2.0
   y = S.y + S.s/2.0
   DrawRect(x,y,S.s,S.s,FillColor=S.c,EdgeWidth=5)
   
def NestedSquare(S):
    """ Returns a green square that has the
    same lower left corner as S but with half the side length
    
    PreC: S is a square
    """
    T = Square(S.x,S.y,S.s/2.0,[0.0,1.0,0.0])
    return T
   
if __name__ == '__main__':
    
    MakeWindow(5)
    S1 = Square(-4,-3,6,[1.0,0.0,0.0])
    T1 = NestedSquare(S1)
    DrawSquare(S1)
    DrawSquare(T1)
    
        
    MakeWindow(5)
    S2 = Square(-4,-3,6,[1.0,0.0,0.0])
    T2 = deepcopy(S2)
    T2.c[1] = 1
    T2.c[0] = 0
    T2.s = T2.s/2.
    DrawSquare(S2)
    DrawSquare(T2)

    
    MakeWindow(5)
    S3 = Square(-4,-3,6,[1.0,0.0,0.0])
    T3 = copy(S3)
    T3.c[1] = 1
    T3.c[0] = 0
    T3.s = T3.s/2.
    DrawSquare(S3)
    DrawSquare(T3)
    
    MakeWindow(5)
    S4 = Square(-4,-3,6,[1.0,0.0,0.0])
    T4 = S4
    T4.c[1] = 1
    T4.c[0] = 0
    T4.s = T4.s/2.
    DrawSquare(S4)
    DrawSquare(T4)

    
    ShowWindow()

    
    

